@@ -25,6 +25,7 @@ GMainContext *_ebook_context;
 
 static GObjectClass *parent_class;
 
+#ifdef __PRETTY_FUNCTION__
 #define e_return_error_if_fail(expr,error_code)	G_STMT_START{		\
      if G_LIKELY(expr) { } else						\
        {								\
@@ -43,6 +44,24 @@ static GObjectClass *parent_class;
 		#expr);							\
 	 return FALSE;							\
        };				}G_STMT_END
+#else
+#define e_return_error_if_fail(expr,error_code)	G_STMT_START{		\
+     if G_LIKELY(expr) { } else						\
+       {								\
+	 g_log (G_LOG_DOMAIN,						\
+		G_LOG_LEVEL_CRITICAL,					\
+		"file %s: line %d: assertion `%s' failed",		\
+		__FILE__,						\
+		__LINE__,						\
+		#expr);							\
+	 g_set_error (error, E_BOOK_ERROR, (error_code),                \
+		"file %s: line %d: assertion `%s' failed",		\
+		__FILE__,						\
+		__LINE__,						\
+		#expr);							\
+	 return FALSE;							\
+       };				}G_STMT_END
+#endif
 
 /* XXX we need a better error message here */
 #define E_BOOK_CHECK_STATUS(status,error) G_STMT_START{			\
@@ -3850,7 +3869,7 @@ e_book_new_system_addressbook    (GError **error)
 		filename = g_build_filename (g_get_home_dir(),
 					     ".evolution/addressbook/local/system",
 					     NULL);
-		uri = g_strdup_printf ("file://%s", filename);
+		uri = g_filename_to_uri (filename, NULL, NULL);
 
 		g_free (filename);
 	
