@@ -129,6 +129,11 @@ e_cal_backend_http_finalize (GObject *object)
 		priv->soup_session = NULL;
 	}
 
+	if (priv->reload_timeout_id) {
+		g_source_remove (priv->reload_timeout_id);
+		priv->reload_timeout_id = 0;
+	}
+
 	g_free (priv);
 	cbhttp->priv = NULL;
 
@@ -639,7 +644,7 @@ e_cal_backend_http_get_object (ECalBackendSync *backend, EDataCal *cal, const ch
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
-	ECalComponent *comp;
+	ECalComponent *comp = NULL;
 
 	cbhttp = E_CAL_BACKEND_HTTP (backend);
 	priv = cbhttp->priv;
@@ -654,7 +659,7 @@ e_cal_backend_http_get_object (ECalBackendSync *backend, EDataCal *cal, const ch
 		return GNOME_Evolution_Calendar_ObjectNotFound;
 
 	*object = e_cal_component_get_as_string (comp);
-	g_free (comp);
+	g_object_unref (comp);
 
 	return GNOME_Evolution_Calendar_Success;
 }
