@@ -114,46 +114,53 @@ void
 camel_offline_store_set_network_state (CamelOfflineStore *store, int state, CamelException *ex)
 {
 	CamelException lex;
-	
+	CamelService *service = CAMEL_SERVICE (store);
+	gboolean network_state = camel_session_get_network_state (service->session);
+
 	if (store->state == state)
 		return;
 	
 	camel_exception_init (&lex);
 	if (store->state == CAMEL_OFFLINE_STORE_NETWORK_AVAIL) {
 		/* network available -> network unavailable */
-		if (((CamelStore *) store)->folders) {
-			GPtrArray *folders;
-			CamelFolder *folder;
-			int i, sync;
-			
-			sync = camel_url_get_param (((CamelService *) store)->url, "sync_offline") != NULL;
-			
-			folders = camel_object_bag_list (((CamelStore *) store)->folders);
-			for (i = 0; i < folders->len; i++) {
-				folder = folders->pdata[i];
+		if (network_state) {
+			if (((CamelStore *) store)->folders) {
+				GPtrArray *folders;
+				CamelFolder *folder;
+				int i, sync;
 				
-				if (CAMEL_CHECK_TYPE (folder, CAMEL_OFFLINE_FOLDER_TYPE)
-				    && (sync || ((CamelOfflineFolder *) folder)->sync_offline)) {
-					camel_offline_folder_downsync ((CamelOfflineFolder *) folder, NULL, &lex);
-					camel_exception_clear (&lex);
+				sync = camel_url_get_param (((CamelService *) store)->url, "sync_offline") != NULL;
+				
+				folders = camel_object_bag_list (((CamelStore *) store)->folders);
+				for (i = 0; i < folders->len; i++) {
+					folder = folders->pdata[i];
+					
+					if (CAMEL_CHECK_TYPE (folder, CAMEL_OFFLINE_FOLDER_TYPE)
+					    && (sync || ((CamelOfflineFolder *) folder)->sync_offline)) {
+						camel_offline_folder_downsync ((CamelOfflineFolder *) folder, NULL, &lex);
+						camel_exception_clear (&lex);
+					}
+					
+					camel_object_unref (folder);
 				}
 				
-				camel_object_unref (folder);
+				g_ptr_array_free (folders, TRUE);
 			}
 			
-			g_ptr_array_free (folders, TRUE);
+			camel_store_sync (CAMEL_STORE (store), FALSE, &lex);
+			camel_exception_clear (&lex);
 		}
-		
-		camel_store_sync (CAMEL_STORE (store), FALSE, &lex);
-		camel_exception_clear (&lex);
-		
-		if (!camel_service_disconnect (CAMEL_SERVICE (store), TRUE, ex))
+
+		if (!camel_service_disconnect (CAMEL_SERVICE (store), network_state, ex))
 			return;
 	} else {
 		/* network unavailable -> network available */
 		if (!camel_service_connect (CAMEL_SERVICE (store), ex))
 			return;
+		fprintf (stderr, "i hit this boo wtf\n");
 	}
 	
+	if (store->state == CAMEL_OFFLINE_STORE_NETWORK_AVAIL) 
+		fprintf (stderr,"I do my job well\n");
 	store->state = state;
 }
