@@ -5,7 +5,7 @@
  *  Copyright 2001-2003 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -29,15 +29,14 @@
 #include <ctype.h>
 #include <unistd.h>
 
-#include <libedataserver/md5-utils.h>
-
-#include <libedataserver/e-iconv.h>
+#include "libedataserver/e-iconv.h"
+#include "libedataserver/md5-utils.h"
 
 #include "camel-charset-map.h"
-#include "camel-mime-utils.h"
-#include "camel-sasl-digest-md5.h"
 #include "camel-i18n.h"
+#include "camel-mime-utils.h"
 #include "camel-net-utils.h"
+#include "camel-sasl-digest-md5.h"
 
 #define d(x)
 
