@@ -10,15 +10,15 @@
  * Copyright 1999 - 2003 Ximian, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -34,16 +34,17 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include "camel-session.h"
-#include "camel-store.h"
-#include "camel-transport.h"
+#include <glib/gstdio.h>
+
 #include "camel-exception.h"
 #include "camel-file-utils.h"
-#include "camel-string-utils.h"
-#include "camel-url.h"
 #include "camel-i18n.h"
-
 #include "camel-private.h"
+#include "camel-session.h"
+#include "camel-store.h"
+#include "camel-string-utils.h"
+#include "camel-transport.h"
+#include "camel-url.h"
 
 #define d(x)
 
@@ -67,6 +68,7 @@ static void
 camel_session_init (CamelSession *session)
 {
 	session->online = TRUE;
+	session->network_state = TRUE;
 	session->priv = g_malloc0(sizeof(*session->priv));
 	
 	session->priv->lock = g_mutex_new();
@@ -277,7 +279,11 @@ get_storage_path (CamelSession *session, CamelService *service, CamelException *
 	path = g_strdup_printf ("%s/%s", session->storage_path, p);
 	g_free (p);
 
+#ifdef G_OS_WIN32 
+	if (g_access (path, F_OK) == 0)
+#else
 	if (access (path, F_OK) == 0)
+#endif
 		return path;
 
 	if (camel_mkdir (path, S_IRWXU) == -1) {
@@ -554,7 +560,7 @@ static void session_thread_wait(CamelSession *session, int id)
 		wait = g_hash_table_lookup(session->priv->thread_active, GINT_TO_POINTER(id)) != NULL;
 		CAMEL_SESSION_UNLOCK(session, thread_lock);
 		if (wait) {
-			usleep(20000);
+			g_usleep(20000);
 		}
 	} while (wait);
 }
@@ -674,3 +680,19 @@ camel_session_set_check_junk (CamelSession *session, gboolean check_junk)
 
 	session->check_junk = check_junk;
 }
+
+gboolean
+camel_session_get_network_state (CamelSession *session)
+{
+	g_return_if_fail (CAMEL_IS_SESSION(session));
+	
+	return session->network_state;
+}
+
+void
+camel_session_set_network_state (CamelSession *session, gboolean network_state)
+{
+	g_return_if_fail (CAMEL_IS_SESSION(session));
+	
+	session->network_state = network_state;
+}
