@@ -766,11 +766,19 @@ imap_command_strdup_vprintf (CamelImapStore *store, const char *fmt,
 		case 'S':
 		case 'F':
 			string = va_arg (ap, char *);
+			/* NB: string is freed during output */
 			if (*p == 'F') {
-				/* NB: this is freed during output */
 				char *s = camel_imap_store_summary_full_from_path(store->summary, string);
-				string = s?s:camel_utf8_utf7(string);
+				if (s) {
+					string = camel_utf8_utf7(s);
+					g_free(s);
+				} else {
+					string = camel_utf8_utf7(string);
+				}
+			} else {
+				string = camel_utf8_utf7(string);
 			}
+				
 			arglen = strlen (string);
 			g_ptr_array_add (args, string);
 			if (imap_is_atom (string)) {
@@ -835,8 +843,7 @@ imap_command_strdup_vprintf (CamelImapStore *store, const char *fmt,
 				}
 			}
 			
-			if (*p == 'F')
-				g_free (string);
+			g_free (string);
 			break;
 		default:
 			*outptr++ = '%';
