@@ -5,7 +5,7 @@
  * Copyright (C) 2005 Novell, Inc.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -132,7 +132,7 @@ get_remember_password (ESource *source)
 	const gchar *value;
 
 	value = e_source_get_property (source, "remember_password");
-	if (value && !strcasecmp (value, "true"))
+	if (value && !g_ascii_strcasecmp (value, "true"))
 		return TRUE;
 
 	return FALSE;
@@ -216,7 +216,7 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 		cb (book, E_BOOK_ERROR_CANCELLED, closure);
 	}
 
-	g_free (uri);
+	g_free (stripped_uri);
 }
 
 static void
