@@ -5,15 +5,15 @@
  * Copyright (C) 2004 Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
@@ -247,6 +247,23 @@ find_destination_by_pointer (EDestinationStore *destination_store, EDestination
 	return -1;
 }
 
+static gint
+find_destination_by_email (EDestinationStore *destination_store, EDestination *destination)
+{
+	gint i;
+	char *e_mail = e_destination_get_email (destination);
+
+	for (i = 0; i < destination_store->destinations->len; i++) {
+		EDestination *destination_here = g_ptr_array_index (destination_store->destinations, i);
+		char *mail = e_destination_get_email (destination_here);
+
+		if (g_str_equal (e_mail, mail))
+			return i;
+	}
+
+	return -1;
+}
+
 static void
 start_destination (EDestinationStore *destination_store, EDestination *destination)
 {
@@ -384,7 +401,7 @@ e_destination_store_append_destination (EDestinationStore *destination_store, ED
 {
 	g_return_if_fail (E_IS_DESTINATION_STORE (destination_store));
 
-	if (find_destination_by_pointer (destination_store, destination) >= 0) {
+	if (find_destination_by_email (destination_store, destination) >= 0 && !e_destination_is_evolution_list (destination)) {
 		g_warning ("Same destination added more than once to EDestinationStore!");
 		return;
 	}
