@@ -51,7 +51,6 @@
 #include <gtk/gtkdialog.h>
 #include <gtk/gtklabel.h>
 
-#include <dirent.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -70,7 +69,8 @@ struct _ExchangeAccountPrivate {
 	ExchangeFolderSize *fsize;
 
 	GMutex *connect_lock;
-	gboolean connecting, connected, account_online;
+	gboolean connecting, connected; 
+	int account_online;
 
 	GPtrArray *hierarchies;
 	GHashTable *hierarchies_by_folder, *foreign_hierarchies;
@@ -160,7 +160,7 @@ init (GObject *object)
 	account->priv->folders = g_hash_table_new (g_str_hash, g_str_equal);
 	account->priv->fresh_folders = NULL;
 	account->priv->discover_data_lock = g_mutex_new ();
-	account->priv->account_online = FALSE;
+	account->priv->account_online = UNSUPPORTED_MODE;
 	account->priv->nt_domain = NULL;
 	account->priv->fsize = exchange_folder_size_new ();
 }
@@ -341,7 +341,7 @@ exchange_account_rescan_tree (ExchangeAccount *account)
 				     toplevel);
 
 		exchange_hierarchy_scan_subtree (account->priv->hierarchies->pdata[i],
-						toplevel, !account->priv->account_online);
+						toplevel, account->priv->account_online);
 		exchange_hierarchy_rescan (account->priv->hierarchies->pdata[i]);
 	}
 }
@@ -362,6 +362,7 @@ hierarchy_new_folder (ExchangeHierarchy *hier, EFolder *folder,
 	/* This makes the cleanup easier. We just unref it each time
 	 * we find it in account->priv->folders.
 	 */
+	d(printf ("adding folder : %s\n", e_folder_get_name (folder)));
 	key = (char *) e_folder_exchange_get_path (folder);
 	if (!g_hash_table_lookup (account->priv->folders, key)) {
 		/* Avoid dupilcations since the user could add a folder as
@@ -511,12 +512,24 @@ exchange_account_create_folder (ExchangeAccount *account,
 	return exchange_hierarchy_create_folder (hier, parent, path, type);
 }
 
+static gboolean
+check_if_sf (gpointer key, gpointer value, gpointer user_data)
+{
+	char *sf_href = (char *)value;
+	char *int_uri = (char *)user_data;
+
+	if (!strcmp (sf_href, int_uri))
+		return TRUE; /* Quit calling the callback */
+
+	return FALSE; /* Continue calling the callback till end of table */
+}
+
 ExchangeAccountFolderResult
 exchange_account_remove_folder (ExchangeAccount *account, const char *path)
 {
 	ExchangeHierarchy *hier;
 	EFolder *folder;
-	const char *name;
+	const char *int_uri;
 
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), 
 				EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
@@ -524,9 +537,12 @@ exchange_account_remove_folder (ExchangeAccount *account, const char *path)
 	if (!get_folder (account, path, &folder, &hier))
 		return EXCHANGE_ACCOUNT_FOLDER_DOES_NOT_EXIST;
 	
-	name = e_folder_get_name (folder);
-	if (exchange_account_get_standard_uri (account, name))
+	int_uri = e_folder_exchange_get_internal_uri (folder);
+
+	if (g_hash_table_find (account->priv->standard_uris, 
+					check_if_sf, (char *)int_uri)) {
 		return EXCHANGE_ACCOUNT_FOLDER_UNSUPPORTED_OPERATION;
+	}
 
 	return exchange_hierarchy_remove_folder (hier, folder);
 }
@@ -766,7 +782,7 @@ exchange_account_open_folder (ExchangeAccount *account, const char *path)
 {
 	ExchangeHierarchy *hier;
 	EFolder *folder;
-	int offline;
+	int mode;
 
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), 
 				EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
@@ -774,8 +790,8 @@ exchange_account_open_folder (ExchangeAccount *account, const char *path)
 	if (!get_folder (account, path, &folder, &hier))
 		return EXCHANGE_ACCOUNT_FOLDER_DOES_NOT_EXIST;
 
-	exchange_account_is_offline (account, &offline);
-	if (offline == ONLINE_MODE && !account->priv->connected &&
+	exchange_account_is_offline (account, &mode);
+	if (mode == ONLINE_MODE && !account->priv->connected &&
 	    hier == (ExchangeHierarchy *)account->priv->hierarchies->pdata[0] &&
 	    folder == hier->toplevel) {
 		/* The shell is asking us to open the personal folders
@@ -785,7 +801,7 @@ exchange_account_open_folder (ExchangeAccount *account, const char *path)
 		return EXCHANGE_ACCOUNT_FOLDER_DOES_NOT_EXIST;
 	}		
 	
-	return exchange_hierarchy_scan_subtree (hier, folder, (offline == OFFLINE_MODE));
+	return exchange_hierarchy_scan_subtree (hier, folder, mode);
 }
 
 ExchangeAccountFolderResult
@@ -904,20 +920,20 @@ account_moved (ExchangeAccount *account, E2kAutoconfig *ac)
 	return TRUE;
 }
 
+#if 0
 static gboolean
 get_password (ExchangeAccount *account, E2kAutoconfig *ac, ExchangeAccountResult error)
 {
 	char *password;
-	gboolean remember, oldremember;
 
 	if (error != EXCHANGE_ACCOUNT_CONNECT_SUCCESS)
 		e_passwords_forget_password ("Exchange", account->priv->password_key);
 
 	password = e_passwords_get_password ("Exchange", account->priv->password_key);
-
+#if 0
 	// SURF : if (exchange_component_is_interactive (global_exchange_component)) {
+		gboolean remember, oldremember;
 		if (!password) {
-	/*
 			char *prompt;
 
 			prompt = g_strdup_printf (_("Enter password for %s"),
@@ -936,7 +952,6 @@ get_password (ExchangeAccount *account, E2kAutoconfig *ac, ExchangeAccountResult
 				account->priv->account->source->save_passwd = remember;
 			}
 			g_free (prompt);
-	*/
 		} 
 		else if (!account->priv->account->source->save_passwd) {
 			/* get_password returns the password cached but user has not 
@@ -945,7 +960,17 @@ get_password (ExchangeAccount *account, E2kAutoconfig *ac, ExchangeAccountResult
 		 	 */
 			e_passwords_forget_password ("Exchange", account->priv->password_key);
 		}
-	// SURF : }
+	}
+#endif
+	if (!password) {
+	}
+	else if (!account->priv->account->source->save_passwd) {
+		/* get_password returns the password cached but user has not 
+	 	 * selected remember password option, forget this password 
+	 	 * whis is stored temporarily by e2k_validate_user() 
+	 	 */
+		e_passwords_forget_password ("Exchange", account->priv->password_key);
+	}
 
 	if (password) {
 		e2k_autoconfig_set_password (ac, password);
@@ -955,6 +980,7 @@ get_password (ExchangeAccount *account, E2kAutoconfig *ac, ExchangeAccountResult
 	} else
 		return FALSE;
 }
+#endif
 
 /* This uses the kerberos calls to check if the authentication failure
  * was due to the password getting expired. If the password has expired
@@ -1108,10 +1134,10 @@ exchange_account_forget_password (ExchangeAccount *account)
 	e_passwords_forget_password ("Exchange", account->priv->password_key);
 }
 
-#ifdef HAVE_KRB5
 ExchangeAccountResult
 exchange_account_set_password (ExchangeAccount *account, char *old_pass, char *new_pass)
 {
+#ifdef HAVE_KRB5
 	E2kKerberosResult result;
 	char *domain;
 
@@ -1157,8 +1183,24 @@ exchange_account_set_password (ExchangeAccount *account, char *old_pass, char *n
 	}
 	
 	return EXCHANGE_ACCOUNT_PASSWORD_CHANGE_SUCCESS;
-}
+#else
+	g_warning ("exchange_account_set_password: Not implemented (no KRB5)");
+	return EXCHANGE_ACCOUNT_PASSWORD_CHANGE_FAILED;
 #endif
+}
+
+void 
+exchange_account_set_save_password (ExchangeAccount *account, gboolean save_password)
+{
+	account->priv->account->source->save_passwd = save_password;
+}
+
+gboolean 
+exchange_account_is_save_password (ExchangeAccount *account)
+{
+	return account->priv->account->source->save_passwd;
+}
+
 
 /**
  * exchange_account_set_offline:
@@ -1183,7 +1225,7 @@ exchange_account_set_offline (ExchangeAccount *account)
 		account->priv->ctx = NULL;
 	}
 
-	account->priv->account_online = FALSE;
+	account->priv->account_online = OFFLINE_MODE;
 	g_mutex_unlock (account->priv->connect_lock);
 	return TRUE;
 }
@@ -1205,7 +1247,7 @@ exchange_account_set_online (ExchangeAccount *account)
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), FALSE);
 
 	g_mutex_lock (account->priv->connect_lock);
-	account->priv->account_online = TRUE;
+	account->priv->account_online = ONLINE_MODE;
 	g_mutex_unlock (account->priv->connect_lock);
 	
 	return TRUE;
@@ -1222,45 +1264,22 @@ exchange_account_is_offline (ExchangeAccount *account, int *state)
 {
 	g_return_if_fail (EXCHANGE_IS_ACCOUNT (account));
 	
-	*state = account->priv->account_online ? ONLINE_MODE : OFFLINE_MODE;
+	*state = account->priv->account_online;
 }
 
-// SURF : Picked this from gal/util/e-util.c
-/* This only makes a filename safe for usage as a filename.  It still may have shell meta-characters in it. */
-static void
-e_filename_make_safe (gchar *string)
-{
-	gchar *p, *ts;
-	gunichar c;
-	
-	g_return_if_fail (string != NULL);
-	p = string;
-
-	while(p && *p) {
-		c = g_utf8_get_char (p);
-		ts = p;
-		p = g_utf8_next_char (p);
-		if (!g_unichar_isprint(c) || ( c < 0xff && strchr (" /'\"`&();|<>$%{}!", c&0xff ))) {
-			while (ts<p) 	
-				*ts++ = '_';
-		}
-	}
-}
-
-
 static gboolean
 setup_account_hierarchies (ExchangeAccount *account)
 {
 	ExchangeHierarchy *hier, *personal_hier;
 	ExchangeAccountFolderResult fresult;
 	char *phys_uri_prefix, *dir;
-	DIR *d;
-	struct dirent *dent;
-	int offline;
+	GDir *d;
+	const char *dent;
+	int mode;
 
-	exchange_account_is_offline (account, &offline);
+	exchange_account_is_offline (account, &mode);
 
-	if (offline == UNSUPPORTED_MODE)
+	if (mode == UNSUPPORTED_MODE)
 		return FALSE;
 
 	/* Check if folder hierarchies are already setup. */
@@ -1323,13 +1342,12 @@ setup_account_hierarchies (ExchangeAccount *account)
 	g_free (phys_uri_prefix);
 
 	/* Other users' folders */
-	d = opendir (account->storage_dir);
+	d = g_dir_open (account->storage_dir, 0, NULL);
 	if (d) {
-		while ((dent = readdir (d))) {
-			if (!strchr (dent->d_name, '@'))
+		while ((dent = g_dir_read_name (d))) {
+			if (!strchr (dent, '@'))
 				continue;
-			dir = g_strdup_printf ("%s/%s", account->storage_dir,
-					       dent->d_name);
+			dir = g_strdup_printf ("%s/%s", account->storage_dir, dent);
 			hier = exchange_hierarchy_foreign_new_from_dir (account, dir);
 			g_free (dir);
 			if (!hier)
@@ -1337,7 +1355,7 @@ setup_account_hierarchies (ExchangeAccount *account)
 
 			setup_hierarchy_foreign (account, hier);
 		}
-		closedir (d);
+		g_dir_close (d);
 	}
 
 hierarchies_created:
@@ -1352,7 +1370,7 @@ hierarchies_created:
 	
 	fresult = exchange_hierarchy_scan_subtree (personal_hier,
 						   personal_hier->toplevel,
-						   (offline == OFFLINE_MODE));
+						   mode);
 	if (fresult != EXCHANGE_ACCOUNT_FOLDER_OK) {
 		account->priv->connecting = FALSE;
 		return FALSE;
@@ -1364,13 +1382,12 @@ hierarchies_created:
 	fresult = exchange_hierarchy_scan_subtree (
 		account->priv->favorites_hierarchy,
 		account->priv->favorites_hierarchy->toplevel,
-		(offline == OFFLINE_MODE));
+		mode);
 	if (fresult != EXCHANGE_ACCOUNT_FOLDER_OK && 
 	    fresult != EXCHANGE_ACCOUNT_FOLDER_DOES_NOT_EXIST) {
 		account->priv->connecting = FALSE;
 		return FALSE;
 	}
-	
 	return TRUE;
 }
 
@@ -1394,30 +1411,31 @@ exchange_account_connect (ExchangeAccount *account, const char *pword,
 	E2kHTTPStatus status;
 	gboolean redirected = FALSE;
 	E2kResult *results;
-	int nresults;
+	int nresults, mode;
 	GByteArray *entryid;
 	const char *timezone;
-	char *old_password, *new_password;
 	E2kGlobalCatalogStatus gcstatus;
 	E2kGlobalCatalogEntry *entry;
 	E2kOperation gcop;
 	char *user_name = NULL;
-	int offline;
 
+	*info_result = EXCHANGE_ACCOUNT_UNKNOWN_ERROR; 
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), NULL);
 
 	*info_result = EXCHANGE_ACCOUNT_CONNECT_SUCCESS;
+	exchange_account_is_offline (account, &mode);
 
-	exchange_account_is_offline (account, &offline);
 	g_mutex_lock (account->priv->connect_lock);
 
-	if ((account->priv->connecting) || (offline == OFFLINE_MODE)){
+	if (account->priv->connecting || mode == OFFLINE_MODE) {
 		g_mutex_unlock (account->priv->connect_lock);
-		if (offline == OFFLINE_MODE) {
+		if (mode == OFFLINE_MODE) {
 			setup_account_hierarchies (account);
-
 			*info_result = EXCHANGE_ACCOUNT_OFFLINE;
 		}
+		else {
+			*info_result = EXCHANGE_ACCOUNT_CONNECT_ERROR;
+		}
 		return NULL;
 	} else if (account->priv->ctx) {
 		g_mutex_unlock (account->priv->connect_lock);
@@ -1441,20 +1459,13 @@ exchange_account_connect (ExchangeAccount *account, const char *pword,
 				      account->priv->ad_limit);
 
 	if (!pword) {
+		account->priv->connecting = FALSE;
 		g_mutex_unlock (account->priv->connect_lock);
+		*info_result = EXCHANGE_ACCOUNT_PASSWORD_INCORRECT;
 		return NULL;
 	}
- try_password_again:
-	if (!pword) {
-/*
-		if (!get_password (account, ac, *info_result)) {
-			account->priv->connecting = FALSE;
-			return NULL;
-		}
-*/
-	} else {
-		e2k_autoconfig_set_password (ac, g_strdup (pword));
-	}
+
+	e2k_autoconfig_set_password (ac, g_strdup (pword));
 
  try_connect_again:
 	account->priv->ctx = e2k_autoconfig_get_context (ac, NULL, &result);
@@ -1471,37 +1482,12 @@ exchange_account_connect (ExchangeAccount *account, const char *pword,
 			account->priv->connecting = FALSE;
 			g_mutex_unlock (account->priv->connect_lock);
 			return NULL;
-/*
-			old_password = exchange_account_get_password (account);
-			//new_password = exchange_get_new_password (old_password, 0);
-
-			if (new_password) {
-				ExchangeAccountResult res;
-				res = exchange_account_set_password (account, old_password, new_password);
-				if (res == EXCHANGE_ACCOUNT_PASSWORD_CHANGE_SUCCESS) {
-					e2k_autoconfig_set_password (ac, new_password);
-					goto try_connect_again;
-				}
-				else
-					*info_result = res;
-				
-				g_free (old_password);
-				g_free (new_password);
-			}
-			else {
-				*info_result = EXCHANGE_ACCOUNT_PASSWORD_EXPIRED;
-				g_free (old_password);
-			}
-
-			result = E2K_AUTOCONFIG_CANCELLED;
-*/
 		}
 #endif
 		switch (result) {
+
 		case E2K_AUTOCONFIG_AUTH_ERROR:
 			*info_result = EXCHANGE_ACCOUNT_PASSWORD_INCORRECT;
-			if (!pword)
-				goto try_password_again;
 			e2k_autoconfig_free (ac);
 			account->priv->connecting = FALSE;
 			g_mutex_unlock (account->priv->connect_lock);
@@ -1509,8 +1495,6 @@ exchange_account_connect (ExchangeAccount *account, const char *pword,
 
 		case E2K_AUTOCONFIG_AUTH_ERROR_TRY_DOMAIN:
 			*info_result = EXCHANGE_ACCOUNT_DOMAIN_ERROR;
-			if (!pword)
-				goto try_password_again;
 			e2k_autoconfig_free (ac);
 			account->priv->connecting = FALSE;
 			g_mutex_unlock (account->priv->connect_lock);
@@ -1540,9 +1524,7 @@ exchange_account_connect (ExchangeAccount *account, const char *pword,
 
 		e2k_autoconfig_free (ac);
 		account->priv->connecting = FALSE;
-
-		// SURF : if (!exchange_component_is_interactive (global_exchange_component))
-			// SURF : return NULL;
+		account->priv->account_online = OFFLINE_MODE; /* correct? */
 
 		switch (result) {
 		case E2K_AUTOCONFIG_REDIRECT:
@@ -1608,6 +1590,10 @@ exchange_account_connect (ExchangeAccount *account, const char *pword,
 			account->default_timezone = g_strdup (timezone);
 	}
 
+	account->priv->connected = TRUE;
+	account->priv->account_online = ONLINE_MODE;
+	account->priv->connecting = FALSE;
+
 	if (!setup_account_hierarchies (account)) {
 		*info_result = EXCHANGE_ACCOUNT_UNKNOWN_ERROR;
 		g_mutex_unlock (account->priv->connect_lock);
@@ -1647,10 +1633,6 @@ exchange_account_connect (ExchangeAccount *account, const char *pword,
 		}
 	}
 	
-	account->priv->connected = TRUE;
-	account->priv->account_online = TRUE;
-	account->priv->connecting = FALSE;
-
 	g_signal_connect (account->priv->ctx, "redirect",
 			  G_CALLBACK (context_redirect), account);
 
@@ -1689,7 +1671,7 @@ E2kContext *
 exchange_account_get_context (ExchangeAccount *account)
 {
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), NULL);
-		
+
 	return account->priv->ctx;
 }
 
@@ -2036,7 +2018,7 @@ ExchangeAccount *
 exchange_account_new (EAccountList *account_list, EAccount *adata)
 {
 	ExchangeAccount *account;
-	char *enc_user, *mailbox, *old_uri_authority;
+	char *enc_user, *mailbox;
 	const char *param, *proto="http", *owa_path, *pf_server, *owa_url; 
 	const char *passwd_exp_warn_period, *offline_sync;
 	E2kUri *uri;
@@ -2068,8 +2050,7 @@ exchange_account_new (EAccountList *account_list, EAccount *adata)
 
 	/* URI, etc, info */
 	enc_user = e2k_uri_encode (uri->user, FALSE, "@/;:");
-	old_uri_authority = g_strdup_printf ("%s@%s", enc_user,
-							uri->host);
+
 	if (uri->authmech)
 		account->priv->uri_authority = g_strdup_printf ("%s;auth=%s@%s", enc_user,
 								uri->authmech, uri->host);
@@ -2084,9 +2065,13 @@ exchange_account_new (EAccountList *account_list, EAccount *adata)
 
 	/* Backword compatibility; FIXME, we should just migrate the
 	 * password from this to source_uri.
+	 * old_uri_authority = g_strdup_printf ("%s@%s", enc_user,
+	 *					uri->host);
+	 * old_uri_authority needs to be used in the key for migrating 
+	 * passwords remembered.
 	 */
-	account->priv->password_key = g_strdup_printf ("exchange://%s", old_uri_authority);
-	g_free (old_uri_authority);
+	account->priv->password_key = g_strdup_printf ("exchange://%s/", 
+							account->priv->uri_authority);
 
 	account->priv->username = g_strdup (uri->user);
 	if (uri->domain)
